@@ -2,7 +2,8 @@ import argparse
 
 from .pycharm_remote_debugger import PycharmRemoteDebugger
 
-
+print("^"*10)
+print("")
 def main():
     parser = argparse.ArgumentParser(description="Pycharm remote debugger")
     parser.add_argument("-r", "--remote", help="Remote machine address", type=str, default="")
@@ -11,9 +12,10 @@ def main():
                         default=False, type=bool, const=True)
     parser.add_argument("-t", "--timeout", help="Connection timeout", type=int,
                         default=PycharmRemoteDebugger.DEFAULT_CONNECTION_TIMEOUT)
+    parser.add_argument("-m", "--module", help="Module to run", type=str, nargs="...")
 
     args = parser.parse_args()
-    debugger = PycharmRemoteDebugger(args.remote, args.port, args.optional)
+    debugger = PycharmRemoteDebugger(args.remote, args.port, args.module, args.optional)
     debugger.wait_for_debugger(args.timeout)
 
 
